@@ -4,7 +4,23 @@ from enum import Enum
 class TradingDataTypes(Enum):
     TICKER = 'TICKER'
     ORDER_BOOK = 'ORDER_BOOK'
-    UN_SPECIFIED = "UN_SPECIFIED"
+    RAW = "RAW"
+
+    @staticmethod
+    def from_value(value):
+
+        if isinstance(value, TradingDataTypes):
+            for trading_data_type in TradingDataTypes:
+
+                if value == trading_data_type:
+                    return trading_data_type
+
+        elif isinstance(value, str):
+            return TradingDataTypes.from_string(value)
+
+        raise ValueError(
+            "Could not convert value to trading data type"
+        )
 
     @staticmethod
     def from_string(value: str):
@@ -16,8 +32,7 @@ class TradingDataTypes(Enum):
                     return order_type
 
         raise ValueError(
-            "Could not convert value to data_provider provider "
-            "data_provider type"
+            "Could not convert value to trading data type"
         )
 
     def equals(self, other):
